@@ -66,8 +66,8 @@ class Element(Widget):
 
     _view_name = Unicode("ElementView").tag(sync=True)
     _model_name = Unicode("ElementModel").tag(sync=True)
-    _view_module = Unicode("map-widget-for-jupyter").tag(sync=True)
-    _model_module = Unicode("map-widget-for-jupyter").tag(sync=True)
+    _view_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
+    _model_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
     _view_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
     _model_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
 
@@ -101,8 +101,8 @@ class Service(Widget):
 
     _view_name = Unicode("ServiceView").tag(sync=True)
     _model_name = Unicode("ServiceModel").tag(sync=True)
-    _view_module = Unicode("map-widget-for-jupyter").tag(sync=True)
-    _model_module = Unicode("map-widget-for-jupyter").tag(sync=True)
+    _view_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
+    _model_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
     _view_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
     _model_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
 
@@ -136,8 +136,8 @@ class Provider(Widget):
 
     _view_name = Unicode("ProviderView").tag(sync=True)
     _model_name = Unicode("ProviderModel").tag(sync=True)
-    _view_module = Unicode("map-widget-for-jupyter").tag(sync=True)
-    _model_module = Unicode("map-widget-for-jupyter").tag(sync=True)
+    _view_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
+    _model_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
     _view_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
     _model_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
 
@@ -281,8 +281,8 @@ class Layer(Widget):
 
     _view_name = Unicode("LayerView").tag(sync=True)
     _model_name = Unicode("LayerModel").tag(sync=True)
-    _view_module = Unicode("map-widget-for-jupyter").tag(sync=True)
-    _model_module = Unicode("map-widget-for-jupyter").tag(sync=True)
+    _view_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
+    _model_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
     _view_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
     _model_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
 
@@ -343,6 +343,7 @@ class GeoJSON(Layer):
     disable_legacy_mode = Bool(True).tag(sync=True)
     style = Dict().tag(sync=True)
     hover_style = Dict().tag(sync=True)
+    point_style = Dict().tag(sync=True)
     evt_type = Unicode("tap").tag(sync=True)
     show_bubble = Bool(False).tag(sync=True)
     style_callback = Any()
@@ -570,8 +571,8 @@ class Object(Widget):
 
     _view_name = Unicode("ObjectView").tag(sync=True)
     _model_name = Unicode("ObjectModel").tag(sync=True)
-    _view_module = Unicode("map-widget-for-jupyter").tag(sync=True)
-    _model_module = Unicode("map-widget-for-jupyter").tag(sync=True)
+    _view_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
+    _model_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
     _view_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
     _model_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
 
@@ -584,8 +585,8 @@ class Geometry(Widget):
 
     _view_name = Unicode("GeometryView").tag(sync=True)
     _model_name = Unicode("GeometryModel").tag(sync=True)
-    _view_module = Unicode("map-widget-for-jupyter").tag(sync=True)
-    _model_module = Unicode("map-widget-for-jupyter").tag(sync=True)
+    _view_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
+    _model_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
     _view_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
     _model_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
 
@@ -1368,8 +1369,8 @@ class Control(Widget):
 
     _view_name = Unicode("ControlView").tag(sync=True)
     _model_name = Unicode("ControlModel").tag(sync=True)
-    _view_module = Unicode("map-widget-for-jupyter").tag(sync=True)
-    _model_module = Unicode("map-widget-for-jupyter").tag(sync=True)
+    _view_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
+    _model_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
     _view_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
     _model_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
 
@@ -1915,8 +1916,8 @@ class Map(DOMWidget, InteractMixin):
 
     _view_name = Unicode("MapView").tag(sync=True)
     _model_name = Unicode("MapModel").tag(sync=True)
-    _view_module = Unicode("map-widget-for-jupyter").tag(sync=True)
-    _model_module = Unicode("map-widget-for-jupyter").tag(sync=True)
+    _view_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
+    _model_module = Unicode("@here/map-widget-for-jupyter").tag(sync=True)
 
     api_key = Unicode("").tag(sync=True)
     center = List(def_loc).tag(sync=True, o=True)
@@ -1924,6 +1925,7 @@ class Map(DOMWidget, InteractMixin):
     heading = Float(180).tag(sync=True, o=True)
     incline = Float(0).tag(sync=True, o=True)
     tilt = Float(0).tag(sync=True, o=True)
+    bounds = Tuple().tag(sync=True, o=True)
 
     layers = Tuple().tag(trait=Instance(Layer), sync=True, **widget_serialization)
     objects = Tuple().tag(trait=Instance(Object), sync=True, **widget_serialization)
